"""
自定义异常类
"""

class LRunException(Exception):

    pass


class NoSuchNodeException(LRunException):
    """
    This is NoSuchNodeException
    """
    pass


class InvalidOperationException(LRunException):
    """
    This is InvalidOperationException
    """
    pass


class TargetTimeout(LRunException):
    """
    This is TargetTimeout
    """
    pass


class ConnectError(LRunException):
    """
    This is ConnectError
    """
    pass


class AdbError(LRunException):
    """
    This is AdbError
    """
    pass


class InvalidParamError(LRunException):
    """
    This is InvalidParamError
    """
    pass




"""
日志工具
"""
import random
import loguru
from typing import Callable
from airtest.core import api as air

import functools
import time
import sys
import os

import logging

# 设置airtest日志等级，debug会输出很多日志
air_logger = logging.getLogger("airtest")
air_logger.setLevel(logging.ERROR)


class Logger:

    """
    通过单例模式，只实例化一个日志对象
    直接调用log实例对象进行日志调用
    """

    def __new__(cls, *args, **kwargs):

        if not hasattr(cls, '_instance'):
            cls._instance = super(Logger, cls).__new__(cls)
        return cls._instance

    def __init__(self):
        """
        添加日志记录器，写入文件
        日志分类型存储，一份完整日志，一份错误日志
        通过读取配置文件中的 IS_WRITE 判断是否需要写入文件，便于调试
        """

        self.logger = loguru.logger
        date = time.strftime("%Y-%m-%d %H-%M-%S", time.localtime(time.time()))
        self.adb_log = None

        # if OUTPUT:
        #     all_log_path = os.path.join(REPORT_DIR, "all.log")
        #     self.logger.add(
        #         all_log_path,  # 日志存放位置
        #         retention=7,  # 清理周期
        #         level="DEBUG",  # 日志级别
        #         enqueue=True,  # 具有使日志记录调用非阻塞的优点
        #         encoding="utf-8",
        #         format=LOG_FORMAT
        #     )
        #     error_log_path = os.path.join(REPORT_DIR, "error.log")
        #     self.logger.add(
        #         error_log_path,
        #         retention=7,
        #         level="ERROR",
        #         enqueue=True,
        #         encoding="utf-8",
        #         format=LOG_FORMAT
        #     )

    def get_logger(self):
        return self.logger

    def random_emoji(self):
        emoji = '🍇🍈🍉🍊🍋🍌🍍🥭🍎🍏🍑🍒🍓🥝🍅🥥🥑🍆🥔🥕🌽🥒🥬🥦🧄🧅🍄🎃🎄🎆🎇🧨✨🎈🎉🎊🎋🎍🎎🎏🍖🍗🥩🥓🍔🍟🍕'
        return random.choice(emoji)

    def step(self, msg):
        self.logger.info(f'{" ".join(self.random_emoji() * 2)} ：{msg}')

    def info(self, msg):
        self.logger.info(msg)

    def debug(self, msg):
        self.logger.debug(msg)

    def warn(self, msg):
        self.logger.warning(f'{" ".join(self.random_emoji() * 2)} ：{msg}')

    def error(self, msg):
        self.logger.error(f'😈 😈 ：{msg}')

    def wrap(self, msg: str = None) -> Callable:
        """
        函数日志装饰器
        :param msg: 消息内容
        :return:
        """
        def wrapper(func):
            @functools.wraps(func)
            def inner(*args, **kwargs):
                start_time = time.time()
                try:
                    res = func(*args, **kwargs)
                    end_time = time.time()
                    duration = round(end_time - start_time, 2)
                    self.step(f"{msg} - func: {func.__name__} - duration: {duration} s")
                    if self.adb_log is not None:
                        air.log(self.adb_log,
                                desc=f"{' '.join(self.random_emoji() * 2)}: {msg} - func: {func.__name__}",
                                snapshot=True)
                    else:
                        air.log(f"{' '.join(self.random_emoji() * 2)}: {msg} - func: {func.__name__}", snapshot=True)
                    self.adb_log = None
                    return res
                except Exception as e:
                    air.log(e, desc=f"😈 😈 : {msg} - func: {func.__name__}", snapshot=True)
                    return func
            return inner
        return wrapper

    def log_adb_out(self, adb_log):
        self.adb_log = adb_log

    def tag(self, msg: str = None) -> Callable:
        """
        函数日志装饰器
        :param msg: 消息内容
        :return:
        """

        def tag_wrapper(func):
            @functools.wraps(func)
            def inner(*args, **kwargs):
                start_time = time.time()
                res = func(*args, **kwargs)
                end_time = time.time()
                duration = round(end_time - start_time, 2)
                self.step(f"{msg} - func: {func.__name__} - duration: {duration} s")
                return res

            return inner

        return tag_wrapper

    def case(self, func: Callable[[str], str]) -> Callable:
        """
        测试用例日志装饰器
        :param func: 用例函数对象
        :return:
        """
        @functools.wraps(func)
        def inner(*args, **kwargs):
            self.step(f"Start running testcase: {func.__name__}")
            start_time = time.time()
            res = func(*args, **kwargs)
            end_time = time.time()
            duration = round(end_time - start_time, 2)
            self.step(f"End running testcase : {func.__name__} [ Case duration: {duration} s ]")
            self.step(f"{'- ' * 16} 分割线 {' -' * 16}")
            return res
        return inner


log = Logger()


if __name__ == '__main__':
    log.info('aaaa')
    log.error('aaaa')
    log.warn('aaaa')
    log.step('aaaa')

    @log.case
    def test():
        log.debug(111)

    test()




#!-*- coding = utf-8 -*-
# @Time : 2024/4/7 2:44
# @Author : 苏嘉浩
# @File : OperateBase.py
# @Software : PyCharm
from abc import ABC, abstractmethod


class OperateABC(ABC):

    @abstractmethod
    def click(self, value, *args, **kwargs):
        pass

    @abstractmethod
    def exists(self, pos, **kwargs):
        pass

    @abstractmethod
    def sleep(self, secs):
        pass

    @abstractmethod
    def swipe(self, value, v2=None, vector_direction=None, **kwargs):
        raise NotImplementedError

    @abstractmethod
    def pinch(self, in_or_out, pos=None, *args, **kwargs):
        pass

    @abstractmethod
    def set_text(self, pos, text,  *args, **kwargs):
        pass

    @abstractmethod
    def wait(self, pos, timeout=None, *args, **kwargs):
        pass

    @abstractmethod
    def wait_disappear_element(self, pos, *args, **kwargs):
        """
        等待元素消失
        :param pos: 元素
        :param args:
        :param kwargs:
        :return:
        """
        pass

    @abstractmethod
    def wait_element_appear(self, pos, *args, **kwargs):
        pass

    @abstractmethod
    def persistent_element_exists(self, pos):
        pass

    def set_dict(self, script_root, project):
        pass

    @abstractmethod
    def wait_for_any(self, pos_list: list, timeout=30):
        pass

    @abstractmethod
    def wait_for_all(self, pos_list: list, timeout=30):
        pass

    @abstractmethod
    def wait_next_element(self, last_click_pos, next_pos):
        pass

    @abstractmethod
    def get_text(self, pos, *args, **kwargs):
        pass


# class OperateClass:
#     def __init__(self, operate: OperateABC):
#         self.operate = operate



import json

import requests

webhook = 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=c7a70ace-36d2-4780-ab47-c0c449e5ae80'

data1 = {
        "msgtype": "template_card",
        "template_card": {
        "card_type":"news_notice",
            "main_title": {
                "title": "包",
                "desc": "试一下"
            },
            # "image_text_area": {
            #     "type": 1,
            #     "url": "http://10.15.162.65:8000/BC/BCuwa_2024-04-02-1257.apk",
            #     "image_url": r"http://10.15.162.65:8000//qrcode_test.png",
            # },
            "card_image": {
                "aspect_ratio": 1,
                "url": "http://10.15.162.65:8000/qrcode_test.png"
            },
            "card_action": {
                "type": 1,
                "url": "http://10.15.162.65:8000/BC/BCuwa_2024-04-02-1257.apk",
            }
        }
    }

data2 = {
    "msgtype": "news",
    "news": {
       "articles": [
           {
               "title": "？？？？",
               "url": "http://10.15.162.65:8000/BC/BCuwa_2024-04-02-1257.apk",
               "picurl": "http://10.15.162.65:8000//IMG_202404021217_145x145.png"
           }
        ]
    }
}

header = {
        "Content-Type": "application/json",
        "Charset": "UTF-8"
}
# date1 = json.dumps(data1)

info = requests.post(url=webhook, json=data1)
print(info.text)
